==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/tool/fragment/src/main/java/org/openscience/cdk/fragment/IFragmenter.java <==
/* Copyright (C) 2010  Rajarshi Guha <rajarshi.guha@gmail.com>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.fragment;

import org.openscience.cdk.exception.CDKException;
import org.openscience.cdk.interfaces.IAtomContainer;

/**
 * An interface for classes implementing fragmentation algorithms.
 *
 * @author Rajarshi Guha
 * @cdk.module  fragment
 * @cdk.githash
 * @cdk.keyword fragment
 */
public interface IFragmenter {

    /**
     * Generate fragments for the input molecule.
     *
     * @param atomContainer The input molecule
     * @throws org.openscience.cdk.exception.CDKException if ring detection fails
     */
    public void generateFragments(IAtomContainer atomContainer) throws CDKException;

    /**
     * Get the fragments generated as SMILES strings.
     *
     * @return a String[] of the fragments.
     */
    public String[] getFragments();

    /**
     * Get fragments generated as {@link IAtomContainer} objects.
     *
     * @return an IAtomContainer[] of fragments
     */
    public IAtomContainer[] getFragmentsAsContainers();
}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/tool/fragment/src/main/java/org/openscience/cdk/fragment/IFragmenter.java <==
/* Copyright (C) 2010  Rajarshi Guha <rajarshi.guha@gmail.com>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.fragment;

import org.openscience.cdk.exception.CDKException;
import org.openscience.cdk.interfaces.IAtomContainer;

/**
 * An interface for classes implementing fragmentation algorithms.
 *
 * @author Rajarshi Guha
 * @cdk.keyword fragment
 */
public interface IFragmenter {

    /**
     * Generate fragments for the input molecule.
     *
     * @param atomContainer The input molecule
     * @throws org.openscience.cdk.exception.CDKException if ring detection fails
     */
    void generateFragments(IAtomContainer atomContainer) throws CDKException;

    /**
     * Get the fragments generated as SMILES strings.
     *
     * @return a String[] of the fragments.
     */
    String[] getFragments();

    /**
     * Get fragments generated as {@link IAtomContainer} objects.
     *
     * @return an IAtomContainer[] of fragments
     */
    IAtomContainer[] getFragmentsAsContainers();
}
